==> OpenTracing-Manual-0.02.tar.gz: OpenTracing-Manual-0.02/README.md <==
## COPYRIGHT NOTICE

'OpenTracing Manual' is Copyright (C) 2020, Perceptyx Inc, Theo van Hoesel

# OpenTracing Manaual

## Description

This Manual is a quick overview of what is available in Perl related to the
OpenTracing API related Interface Definition.

It targets three different audiences:

- Application developers and Devops
- Framwork or Integration Developers
- Tracing service Implementation providers

Included is a list of Perl Modules and those that are on the horizon.

## Introduction

From the OpenTracing IO website:

> OpenTracing is comprised of an API specification, frameworks and libraries
> that have implemented the specification, and documentation for the project.
> OpenTracing allows developers to add instrumentation to their application code
> using APIs that do not lock them into any one particular product or vendor.

> Distributed tracing, also called distributed request tracing, is a method used
> to profile and monitor applications, especially those built using a
> microservices architecture. Distributed tracing helps pinpoint where failures
> occur and what causes poor performance.

See also: [OpenTracing Overview](https://opentracing.io/docs/overview/).

## LICENSE INFORMATION

This library is free software; you can redistribute it and/or modify it under
the terms of the Artistic License 2.0.

This library is distributed in the hope that it will be useful, but it is
provided “as is” and without any express or implied warranties.

For details, see the full text of the license in the file LICENSE.

==> OpenTracing-Manual-0.05.tar.gz: OpenTracing-Manual-0.05/README.md <==
## COPYRIGHT NOTICE

'OpenTracing Manual' is Copyright (C) 2020, Perceptyx Inc, Theo van Hoesel

# OpenTracing Manual

## Description

This Manual is a quick overview of what is available in Perl related to the
OpenTracing API related Interface Definition.

It targets three different audiences:

- Application developers and Devops
- Framework or Integration Developers
- Tracing service Implementation providers

Included is a list of Perl Modules and those that are on the horizon.

## Introduction

From the OpenTracing IO website:

> OpenTracing is comprised of an API specification, frameworks and libraries
> that have implemented the specification, and documentation for the project.
> OpenTracing allows developers to add instrumentation to their application code
> using APIs that do not lock them into any one particular product or vendor.

> Distributed tracing, also called distributed request tracing, is a method used
> to profile and monitor applications, especially those built using a
> microservices architecture. Distributed tracing helps pinpoint where failures
> occur and what causes poor performance.

See also: [OpenTracing Overview](https://opentracing.io/docs/overview/).

## LICENSE INFORMATION

This library is free software; you can redistribute it and/or modify it under
the terms of the Artistic License 2.0.

This library is distributed in the hope that it will be useful, but it is
provided “as is” and without any express or implied warranties.

For details, see the full text of the license in the file LICENSE.
